@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -165,7 +165,7 @@ gpk_watch_get_restart_required_tooltip (GpkWatch *watch)
 		}
 
 		/* join */
-		text = g_strdup_printf ("%s%s", title, message);
+		text = g_strdup_printf ("%s %s", title, message);
 		goto out;
 	}
 
@@ -1189,6 +1189,7 @@ static void
 gpk_watch_button_cancel_cb (GtkWidget *widget, GpkWatch *watch)
 {
 	/* we might have a transaction running */
+	egg_debug ("cancelling transaction: %p", watch->priv->cancellable);
 	g_cancellable_cancel (watch->priv->cancellable);
 }
 
@@ -1198,10 +1199,8 @@ gpk_watch_button_cancel_cb (GtkWidget *widget, GpkWatch *watch)
 static void
 gpk_watch_set_connected (GpkWatch *watch, gboolean connected)
 {
-	if (!connected) {
-		gtk_status_icon_set_visible (watch->priv->status_icon, FALSE);
+	if (!connected)
 		return;
-	}
 
 	/* daemon has just appeared */
 	egg_debug ("dameon has just appeared");
@@ -1279,10 +1278,10 @@ out:
 }
 
 /**
- * pk_watch_process_messages_cb:
+ * gpk_watch_process_messages_cb:
  **/
 static void
-pk_watch_process_messages_cb (PkMessage *item, GpkWatch *watch)
+gpk_watch_process_messages_cb (PkMessage *item, GpkWatch *watch)
 {
 	gboolean ret;
 	GError *error = NULL;
@@ -1346,10 +1345,10 @@ out:
 }
 
 /**
- * pk_watch_process_error_code:
+ * gpk_watch_process_error_code:
  **/
 static void
-pk_watch_process_error_code (GpkWatch *watch, PkError *error_code)
+gpk_watch_process_error_code (GpkWatch *watch, PkError *error_code)
 {
 	gboolean ret;
 	GError *error = NULL;
@@ -1409,10 +1408,10 @@ out:
 }
 
 /**
- * pk_watch_process_require_restart_cb:
+ * gpk_watch_process_require_restart_cb:
  **/
 static void
-pk_watch_process_require_restart_cb (PkRequireRestart *item, GpkWatch *watch)
+gpk_watch_process_require_restart_cb (PkRequireRestart *item, GpkWatch *watch)
 {
 	GPtrArray *array = NULL;
 	GPtrArray *names = NULL;
@@ -1429,24 +1428,30 @@ pk_watch_process_require_restart_cb (PkRequireRestart *item, GpkWatch *watch)
 		      NULL);
 
 	/* if less important than what we are already showing */
-	if (restart <= watch->priv->restart)
+	if (restart <= watch->priv->restart) {
+		egg_debug ("restart already %s, not processing %s",
+			   pk_restart_enum_to_text (watch->priv->restart),
+			   pk_restart_enum_to_text (restart));
 		goto out;
+	}
+
+	/* save new restart */
+	watch->priv->restart = restart;
 
 	/* add name if not already in the list */
 	split = pk_package_id_split (package_id);
 	names = watch->priv->restart_package_names;
 	for (i=0; i<names->len; i++) {
 		name = g_ptr_array_index (names, i);
-		if (g_strcmp0 (name, split[PK_PACKAGE_ID_NAME]) == 0)
-			break;
-	}
-	if (i < names->len) {
-		/* add to list */
-		g_ptr_array_add (names, g_strdup (split[PK_PACKAGE_ID_NAME]));
+		if (g_strcmp0 (name, split[PK_PACKAGE_ID_NAME]) == 0) {
+			egg_debug ("already got %s", name);
+			goto out;
+		}
 	}
 
-	/* save new restart */
-	watch->priv->restart = restart;
+	/* add to list */
+	egg_warning ("adding %s to restart list", split[PK_PACKAGE_ID_NAME]);
+	g_ptr_array_add (names, g_strdup (split[PK_PACKAGE_ID_NAME]));
 out:
 	g_free (package_id);
 	g_strfreev (split);
@@ -1494,35 +1499,40 @@ gpk_watch_adopt_cb (PkClient *client, GAsyncResult *res, GpkWatch *watch)
 		      "elapsed-time", &elapsed_time,
 		      NULL);
 
-	/* is not the watched transaction */
-	if (g_strcmp0 (transaction_id, watch->priv->transaction_id) != 0)
-		goto out;
+	egg_warning ("%s finished (%s)", transaction_id, pk_role_enum_to_text (role));
 
-	/* stop spinning */
-	gpk_modal_dialog_set_percentage (watch->priv->dialog, 100);
-
-	/* autoclose if success */
+	/* get the error */
 	error_code = pk_results_get_error_code (results);
-	if (error_code == NULL)
-		gpk_modal_dialog_close (watch->priv->dialog);
+
+	/* is the watched transaction */
+	if (g_strcmp0 (transaction_id, watch->priv->transaction_id) == 0) {
+		egg_debug ("watched transaction %s", watch->priv->transaction_id);
+
+		/* stop spinning */
+		gpk_modal_dialog_set_percentage (watch->priv->dialog, 100);
+
+		/* autoclose if success */
+		if (error_code == NULL)
+			gpk_modal_dialog_close (watch->priv->dialog);
+	}
 
 	/* process messages */
 	if (error_code == NULL) {
 		array = pk_results_get_message_array (results);
-		g_ptr_array_foreach (array, (GFunc) pk_watch_process_messages_cb, watch);
+		g_ptr_array_foreach (array, (GFunc) gpk_watch_process_messages_cb, watch);
 		g_ptr_array_unref (array);
 	}
 
 	/* only process errors if caller is no longer on the bus */
 	if (error_code != NULL && !caller_active)
-		pk_watch_process_error_code (watch, error_code);
+		gpk_watch_process_error_code (watch, error_code);
 
 	/* process restarts */
 	if (role == PK_ROLE_ENUM_UPDATE_PACKAGES ||
 	    role == PK_ROLE_ENUM_INSTALL_PACKAGES ||
 	    role == PK_ROLE_ENUM_UPDATE_SYSTEM) {
 		array = pk_results_get_require_restart_array (results);
-		g_ptr_array_foreach (array, (GFunc) pk_watch_process_require_restart_cb, watch);
+		g_ptr_array_foreach (array, (GFunc) gpk_watch_process_require_restart_cb, watch);
 		g_ptr_array_unref (array);
 	}
 
@@ -1663,7 +1673,7 @@ gpk_watch_transaction_list_added_cb (PkTransactionList *tlist, const gchar *tran
 		return;
 	}
 	egg_debug ("added: %s", transaction_id);
-	pk_client_adopt_async (PK_CLIENT(watch->priv->task), transaction_id, NULL,
+	pk_client_adopt_async (PK_CLIENT(watch->priv->task), transaction_id, watch->priv->cancellable,
 			       (PkProgressCallback) gpk_watch_progress_cb, watch,
 			       (GAsyncReadyCallback) gpk_watch_adopt_cb, watch);
 }
